FromAnyRow

Trait FromAnyRow 

pub trait FromAnyRow: Sized {
    // Required methods
    fn from_any_row(row: &AnyRow) -> Result<Self, Error>;
    fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>;
}
A trait for types that can be mapped from an AnyRow.

Required Methods

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Constructs the type from the whole row.

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Constructs the type from the row starting at the given index, incrementing the index for each column consumed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FromAnyRow for bool

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for f32

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for f64

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for i8

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for i16

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for i32

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for i64

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for isize

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for u8

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for u16

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for u32

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for u64

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for usize

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for String

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for DateTime<Utc>

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for NaiveDate

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for NaiveDateTime

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for NaiveTime

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl FromAnyRow for Uuid

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow> FromAnyRow for (T1,)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow> FromAnyRow for (T1, T2)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow, T3: FromAnyRow> FromAnyRow for (T1, T2, T3)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow, T3: FromAnyRow, T4: FromAnyRow> FromAnyRow for (T1, T2, T3, T4)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow, T3: FromAnyRow, T4: FromAnyRow, T5: FromAnyRow> FromAnyRow for (T1, T2, T3, T4, T5)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow, T3: FromAnyRow, T4: FromAnyRow, T5: FromAnyRow, T6: FromAnyRow> FromAnyRow for (T1, T2, T3, T4, T5, T6)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow, T3: FromAnyRow, T4: FromAnyRow, T5: FromAnyRow, T6: FromAnyRow, T7: FromAnyRow> FromAnyRow for (T1, T2, T3, T4, T5, T6, T7)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T1: FromAnyRow, T2: FromAnyRow, T3: FromAnyRow, T4: FromAnyRow, T5: FromAnyRow, T6: FromAnyRow, T7: FromAnyRow, T8: FromAnyRow> FromAnyRow for (T1, T2, T3, T4, T5, T6, T7, T8)

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Source

impl<T: FromAnyRow> FromAnyRow for Option<T>

Source

fn from_any_row(row: &AnyRow) -> Result<Self, Error>

Source

fn from_any_row_at(row: &AnyRow, index: &mut usize) -> Result<Self, Error>

Implementors