pub struct DatabaseBuilder { /* private fields */ }Expand description
A builder for creating a Database connection with custom options.
Allows configuration of connection pool settings such as maximum connections, timeouts, and lifetimes.
Example
ⓘ
let db = Database::builder()
.max_connections(10)
.min_connections(2)
.acquire_timeout(std::time::Duration::from_secs(5))
.connect("postgres://...")
.await?;Implementations
Sourceimpl DatabaseBuilder
impl DatabaseBuilder
Sourcepub fn max_connections(self, max: u32) -> Self
pub fn max_connections(self, max: u32) -> Self
Sets the maximum number of connections that this pool should maintain.
Sourcepub fn min_connections(self, min: u32) -> Self
pub fn min_connections(self, min: u32) -> Self
Sets the minimum number of connections that this pool should maintain.
Sourcepub fn acquire_timeout(self, timeout: Duration) -> Self
pub fn acquire_timeout(self, timeout: Duration) -> Self
Sets the maximum amount of time to spend waiting for a connection.
Sourcepub fn idle_timeout(self, timeout: Duration) -> Self
pub fn idle_timeout(self, timeout: Duration) -> Self
Sets the maximum amount of time a connection may be idle.
Sourcepub fn max_lifetime(self, lifetime: Duration) -> Self
pub fn max_lifetime(self, lifetime: Duration) -> Self
Sets the maximum lifetime of a connection.