Module transaction

Module transaction 

Transaction Module

This module provides the transaction management functionality for Bottle ORM. It allows executing multiple database operations atomically, ensuring data consistency.

Structs

Transaction
A wrapper around a SQLx transaction.