Support for mapping arbitrary AnyRow results to structs.
Defines traits and structures (AnyImpl, AnyInfo) that support the FromAnyRow
derive macro, enabling flexible result mapping.
Structs
- AnyInfo
- Contains metadata about a database column.
Traits
- AnyImpl
- A trait for types that can be mapped from an
AnyRowand provide column metadata. - From
AnyRow - A trait for types that can be mapped from an
AnyRow.