Module any_struct

Module any_struct 

Support for mapping arbitrary AnyRow results to structs.

Defines traits and structures (AnyImpl, AnyInfo) that support the FromAnyRow derive macro, enabling flexible result mapping.

Structs

AnyInfo
Contains metadata about a database column.

Traits

AnyImpl
A trait for types that can be mapped from an AnyRow and provide column metadata.
FromAnyRow
A trait for types that can be mapped from an AnyRow.