pub trait FromAnyRow: Sized {
// Required method
fn from_any_row(row: &AnyRow) -> Result<Self, Error>;
}Expand description
A trait for types that can be mapped from an AnyRow.
This trait replaces sqlx::FromRow for bottle-orm to support
Tuple mapping where each element constructs itself from the whole row
(e.g. (User, Account)), rather than consuming columns positionally.
Required Methods
fn from_any_row(row: &AnyRow) -> Result<Self, Error>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.